<?php
/**
 * $Horde: whups/lib/Forms/EditTicket.php,v 1.8 2007/02/08 16:47:37 jan Exp $
 *
 * Basic Ticket Editing form.
 *
 * @author  Chuck Hagenbuch <chuck@horde.org>
 * @package Whups
 */
class EditTicketForm extends Horde_Form {

    function EditTicketForm(&$vars, $title = '', $attributes = null)
    {
        global $whups;

        parent::Horde_Form($vars, $title);
        $type = $vars->get('type');

        $start_year = date('Y');
        if ($vars->get('due')) {
            $start_year = min($start_year, date('Y', $vars->get('due')));
        }

        $this->addHidden('', 'id', 'int', true, true);
        $this->addHidden('', 'type', 'int', true, true);

        /* Standard ticket fields. */
        $this->addVariable(_("Summary"), 'summary', 'text', true);
        $this->addVariable(_("State"), 'state', 'enum', true, false, null, array($whups->getStates($type)));
        $this->addVariable(_("Priority"), 'priority', 'enum', true, false, null, array($whups->getPriorities($type)));
        $this->addVariable(_("Due Date"), 'due', 'datetime', false, false, null, array($start_year));

        /* Ticket attributes. */
        $attribute_array = $whups->getAttributesForType($type);
        foreach ($attribute_array as $id => $attribute) {
            $var = &$this->addVariable($attribute['human_name'],
                                       'a' . $id,
                                       $attribute['type'],
                                       $attribute['required'],
                                       $attribute['readonly'],
                                       $attribute['desc'],
                                       $attribute['params']);
            if (isset($attributes[$id]['value'])) {
                $var->setDefault($attributes[$id]['value']);
            }
        }

        /* Users and Groups. */
        if (Whups::hasPermission(array($vars->get('queue')), 'queue',
                                 'assign', Auth::getAuth())) {
            $groups = &Group::singleton();
            if ($GLOBALS['conf']['prefs']['assign_all_groups']) {
                $mygroups = $groups->listGroups();
            } else {
                $mygroups = $groups->getGroupMemberships(Auth::getAuth());
            }

            $f_users = array();
            $users = $whups->getQueueUsers($vars->get('queue'));
            foreach ($users as $user) {
                $f_users['user:' . $user] = Whups::formatUser($user);
            }

            $f_groups = array();
            if ($mygroups) {
                foreach (array_keys($mygroups) as $id) {
                    $f_groups['group:' . $id] = $groups->getGroupName($id, true);
                }
            }

            if (count($f_users)) {
                asort($f_users);
                $owners = &$this->addVariable(_("Owners"), 'owners', 'multienum', false, false, null, array($f_users));
                $owners->setDefault($whups->getOwners($vars->get('id')));
            }

            if (count($f_groups)) {
                asort($f_groups);
                $group_owners = &$this->addVariable(_("Group Owners"), 'group_owners', 'multienum', false, false, null, array($f_groups));
                $group_owners->setDefault($whups->getOwners($vars->get('id')));
            }
        }

        /* Attachments and Comments. */
        $this->addVariable(_("Attachment"), 'newattachment', 'file', false);
        $this->addVariable(_("Comment"), 'newcomment', 'longtext', false);

        /* Comment Permissions. */
        $groups = &Group::singleton();
        $mygroups = $groups->getGroupMemberships(Auth::getAuth());
        if ($mygroups) {
            foreach (array_keys($mygroups) as $gid) {
                $grouplist[$gid] = $groups->getGroupName($gid, true);
            }
            asort($grouplist);
            $grouplist = array_merge(array(0 => _("Any Group")), $grouplist);
            $this->addVariable(_("Restrict Comment to:"), 'group', 'enum', true, false, null, array($grouplist));
        }
    }

    function validate(&$vars)
    {
        if (!Auth::getAuth()) {
            $this->setError('_auth', _("Permission Denied."));
        }

        return parent::validate($vars);
    }

}
