<?php
/**
 * $Horde: whups/search.php,v 1.104 2007/01/18 03:40:40 chuck Exp $
 *
 * Copyright 2001-2006 Robert E. Coyle <robertecoyle@hotmail.com>
 * Copyright 2001-2007 The Horde Project (http://www.horde.org/)
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 *
 * @author Chuck Hagenbuch <chuck@horde.org>
 */

@define('WHUPS_BASE', dirname(__FILE__));
require_once WHUPS_BASE . '/lib/base.php';
require_once WHUPS_BASE . '/lib/Query.php';
require_once WHUPS_BASE . '/lib/Forms/Search.php';
require_once 'Horde/Variables.php';
require_once WHUPS_TEMPLATES . '/searchresults.inc';
require_once WHUPS_TEMPLATES . '/savedqueries.inc';

$renderer = new Horde_Form_Renderer();
$beendone = 0;
$vars = Variables::getDefaultVariables();

$title = _("Search");
require WHUPS_TEMPLATES . '/common-header.inc';
require WHUPS_TEMPLATES . '/menu.inc';

// Update sorting preferences.
if (Util::getFormData('sortby') !== null) {
    $prefs->setValue('sortby', Util::getFormData('sortby'));
}
if (Util::getFormData('sortdir') !== null) {
    $prefs->setValue('sortdir', Util::getFormData('sortdir'));
}

$form = new SearchForm($vars);
if ($vars->get('category') && $form->validate($vars, true)) {
    $form->getInfo($vars, $info);

    $cat = $vars->get('category');
    $type = $vars->get('type');
    $summary = $vars->get('summary');

    $qUrl = Util::addParameter('', array('queue' => $vars->get('queue')));
    if ($summary) {
        $qUrl = Util::addParameter($qUrl, 'summary', $summary);
    }
    if (is_array($cat)) {
        foreach ($cat as $c) {
            $qUrl = Util::addParameter($qUrl, 'category[]', $c);
        }
    }
    if (is_array($type)) {
        foreach ($type as $t) {
            $qUrl = Util::addParameter($qUrl, 'type[]', $t);
        }
    }
    $qUrl = substr($qUrl, 1);
    $_SESSION['whups_last_search'] = Horde::applicationUrl("search.php?$qUrl");

    // Munge the search criteria into acceptability.
    if (empty($info['queue'])) {
        $info['queue'] = array_keys(Whups::permissionsFilter($whups->getQueues(), 'queue', PERMS_READ, Auth::getAuth(), Auth::getAuth()));
    }
    if (empty($info['category'])) {
        unset($info['category']);
    }
    if (empty($info['type'])) {
        unset($info['type']);
    }

    $tickets = $whups->getTicketsByProperties($info);
    if (is_a($tickets, 'PEAR_Error')) {
        $notification->push(sprintf(_("There was an error performing your search: %s"), $tickets->getMessage()), 'horde.error');
    } else {
        Whups::sortTickets($tickets);

        $values = Whups::getSearchResultColumns();

        $results = new SearchResults(_("Search Results"));
        $results->results($tickets, $values);
        $beendone = 1;

        if (is_object($form)) {
            $form->setTitle(_("Refine Search"));
            $form->renderActive($renderer, $vars, 'search.php', 'get');
            echo '<br />';

            $beendone = 1;
        }
    }
}

if (!$beendone) {
    // Front search page.
    $form->setTitle(_("Ticket Search"));
    $form->renderActive($renderer, $vars, 'search.php', 'get');
    echo '<br class="spacer" />';
}

if (Auth::getAuth()) {
    $qManager = new Whups_QueryManager();
    $myqueries = new SavedQueries();
    $myqueries->render(_("My Queries"), $renderer, $qManager->listQueries(Auth::getAuth()));
}

require $registry->get('templates', 'horde') . '/common-footer.inc';
