<?php

require_once 'Horde/UI/VarRenderer.php';
require_once 'Horde/UI/VarRenderer/html.php';

/**
 * $Horde: whups/templates/queryrenderer.inc,v 1.43 2007/01/18 02:38:01 chuck Exp $
 *
 * Copyright 2001 Robert E. Coyle <robertecoyle@hotmail.com>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 */
class QuerySetCurrentTypeRenderer extends Horde_Form_Renderer {

    function _renderForm(&$form, &$vars, $isActive)
    {
        global $whups, $whups_query;

        $droptext = Horde_UI_VarRenderer_html::_selectOptions($whups->getAllTypes());
?>
<tr class="item0"><td>
 <table cellspacing="4">
  <tr class="item0">
   <td nowrap="nowrap"><strong><?php echo _("Current Ticket Type") ?></strong></td>
   <td><select name="ttype"><?php echo $droptext ?></select></td>
   <td><input class="button" type="submit" value="<?php echo _("Change") ?>" /></td>
   <td width="70%">&nbsp;</td>
  </tr>
 </table>
</td></tr>
<?php
    }

    function submit()
    {
    }

}

class QueryRenderer extends Horde_Form_Renderer {

    function QueryRenderer()
    {
        global $whups;
        $this->ticketTypes = $whups->getAllTypes();
    }

    function _renderForm(&$query, &$vars, $active)
    {
        $this->currentRow = 1;
        $this->isActive = $active;
        $this->currentPath = $vars->get('path');

        $this->_renderBegin();
        $query->walk($this, '_renderRow');
        $this->_renderEnd();
    }

    function edit(&$operations, $formname)
    {
?>
<tr><td class="item1"><table cellspacing="3"><tr><td>
 <select name="qaction" onchange="document.<?php echo $formname ?>.submit()">
<?php foreach ($operations as $value => $name) { ?>
  <option value="<?php echo $value ?>"><?php echo $name ?></option>
<?php } ?>
 </select>
</td></tr></table></td></tr>
<?php
    }

    function _renderBegin()
    {
?><table class="item"><?php
    }

    function _renderRow(&$more, &$path, $type, $criterion, $cvalue, $operator, $value)
    {
        global $whups, $registry;

        $this->currentRow++;

        $pathstring = Whups_Query::pathToString($path);

        $depth = count($path);
        $class = "item" . ($this->currentRow % 2);

        switch ($type) {
        case QUERY_TYPE_AND: $text = _("And"); break;
        case QUERY_TYPE_OR:  $text = _("Or");  break;
        case QUERY_TYPE_NOT: $text = _("Not"); break;
        case QUERY_TYPE_CRITERION:

            switch ($criterion) {
            case CRITERION_ID:             $text = _("Id"); break;
            case CRITERION_OWNERS:         $text = _("Owners"); break;
            case CRITERION_GROUPS:         $text = _("Groups"); break;
            case CRITERION_REQUESTER:      $text = _("Requester"); break;
            case CRITERION_ADDED_COMMENT:  $text = _("Commentor"); break;
            case CRITERION_COMMENT:        $text = _("Comment"); break;
            case CRITERION_SUMMARY:        $text = _("Summary"); break;

            case CRITERION_QUEUE:
                $queue = $whups->getQueue($value);
                if ($queue) {
                    $text = _("Queue");
                    $value = $queue['name'];
                }
                break;

            case CRITERION_VERSION:
                $version = $whups->getVersion($value);
                if ($version) {
                    $text = _("Version");
                    $value = $version['name'];
                }
                break;

            case CRITERION_TYPE:
                $text = _("Type");
                $value = $whups->getTypeName($value);
                break;

                // the value of the following depend on ttype
            case CRITERION_STATE:
                $state = $whups->getState($value);
                if ($state && isset($this->ticketTypes[$state['type']])) {
                    $text = '[' . $this->ticketTypes[$state['type']] . '] ' .
                        _("State");
                    $value = $state['name'];
                }
                break;

            case CRITERION_PRIORITY:
                $state = $whups->getPriority($value);
                $text = '[' . $this->ticketTypes[$state['type']] . '] ' .
                    _("Priority");
                $value = $state['name'];
                break;

            case CRITERION_ATTRIBUTE:
                $aname = $whups->getAttributeName($cvalue);
                $text = sprintf("Attribute \"%s\"", $aname);
            }

            if (!isset($text)) {
                $text = sprintf(_("Unknown node type %s"), $type);
                break;
            }

            $text .= ' ';

            switch ($operator) {
            case OPERATOR_GREATER:
                $text .= _("is greater than");
                break;

            case OPERATOR_LESS:
                $text .= _("is less than");
                break;

            case OPERATOR_EQUAL:
                $text .= _("is");
                break;

            case OPERATOR_CI_SUBSTRING:
                $text .= _("contains (case insensitive) substring");
                break;

            case OPERATOR_CS_SUBSTRING:
                $text .= _("contains (case sensitive) substring");
                break;

            case OPERATOR_WORD:
                $text .= _("contains the word");
                break;

            case OPERATOR_PATTERN:
                $text .= _("matches the pattern");
                break;
            }

            $text .= " $value";
            break;

        default:
            $text = sprintf(_("Unknown node type %s"), $type);
            break;
        }

        // Stick vertical-align: middle; on everything to make it look a
        // little nicer.
        $fimgattrs = 'height="20" width="0" style="vertical-align: middle;"';
        $imgattrs = 'height="20" width="20" style="vertical-align: middle;"';
        $imgdir = $registry->getImageDir('horde');

        $space = '';
        $count = count($more);

        if ($count == 0) {
            // Always have at least one image to make sure all rows are the
            // same height.
            $space = Horde::img('tree/blank.png', '', $fimgattrs, $imgdir) . "\n";
        } else {
            for ($i = 0; $i < $count - 1; $i++) {
                if ($more[$i] == 1) {
                    $space .= Horde::img('tree/line.png', '|', $imgattrs, $imgdir) . "\n";
                } else {
                    $space .= Horde::img('tree/blank.png', '', $imgattrs, $imgdir) . "\n";
                }
            }
        }

        if ($count > 0) {
            if ($more[$count - 1] == 1) {
                $space .= Horde::img('tree/join.png', '+', $imgattrs, $imgdir) . "\n";
            } else {
                $space .= Horde::img('tree/joinbottom.png', '-', $imgattrs, $imgdir) . "\n";
            }
        }

        $extra  = ($this->isActive ? '' : ' disabled="disabled"');
        $extra .= ($pathstring == $this->currentPath ? ' checked="checked"' : '');
?>
 <tr><td class="<?php echo $class ?>">
  <input type="radio" name="path" style="vertical-align: middle;" value="<?php echo $pathstring ?>"<?php echo $extra ?>/>
  <?php echo $space ?>
  <span style="vertical-align: middle;"><?php echo $text ?></span>
 </td></tr>
<?php
    }

    function _renderEnd()
    {
        echo '</table>';
    }

}
