<?php
/**
 * $Horde: whups/ticket/delete.php,v 1.14 2006/08/08 19:00:41 chuck Exp $
 *
 * Copyright 2001-2006 Robert E. Coyle <robertecoyle@hotmail.com>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 */

@define('WHUPS_BASE', dirname(__FILE__) . '/..');
require_once WHUPS_BASE . '/lib/base.php';
require_once WHUPS_BASE . '/lib/Ticket.php';
require_once 'Horde/Variables.php';

if (!Auth::isAdmin('whups:admin')) {
    $notification->push(_("Permission Denied"), 'horde.error');
    header('Location: ' . Horde::applicationUrl($prefs->getValue('whups_default_view') . '.php', true));
    exit;
}

class DeleteTicketForm extends Horde_Form {

    function DeleteTicketForm(&$vars, $title = '')
    {
        global $whups;

        parent::Horde_Form($vars, $title, 'deleteticketform');

        $info = $whups->getTicketDetails($vars->get('id'));

        $this->addHidden('', 'id', 'int', true, true);

        $summary = &$this->addVariable(_("Summary"), 'summary', 'text', false, true);
        $summary->setDefault($info['summary']);

        $yesno = array(0 => _("No"), 1 => _("Yes"));
        $this->addVariable(_("Really delete this ticket? It will NOT be archived, and will be gone forever."), 'yesno', 'enum', true, false, null, array($yesno));
    }

    function validate(&$vars)
    {
        if (!Auth::isAdmin('whups:admin')) {
            $this->setError('yesno', _("Permission Denied."));
        }

        return parent::validate($vars);
    }

}

$ticket = Whups::getCurrentTicket();
$vars = Variables::getDefaultVariables();
$vars->set('id', $id = $ticket->getId());
foreach ($ticket->getDetails() as $varname => $value) {
    $vars->add($varname, $value);
}
$title = sprintf(_("Delete %s?"), '[#' . $id . '] ' . $ticket->get('summary'));
$deleteform = &new DeleteTicketForm($vars, $title);

if ($vars->get('formname') == 'deleteticketform') {
    if ($deleteform->validate($vars)) {
        if ($vars->get('yesno') == 1) {
            $deleteform->getInfo($vars, $info);
            $result = $whups->deleteTicket($info);

            if (!is_a($result, 'PEAR_Error')) {
                $notification->push(sprintf(_("Ticket %d has been deleted."), $info['id']), 'horde.success');
                header('Location: ' . Horde::applicationUrl($prefs->getValue('whups_default_view') . '.php', true));
                exit;
            } else {
                $notification->push(sprintf(_("There was an error deleting the ticket: %s"), $result->getMessage()), 'horde.error');
            }
        } else {
            $notification->push(_("The ticket was not deleted."), 'horde.message');
        }
    }
}

require WHUPS_TEMPLATES . '/common-header.inc';
require WHUPS_TEMPLATES . '/menu.inc';
require WHUPS_TEMPLATES . '/prevnext.inc';

$tabs = Whups::getTicketTabs($vars);
$tabs->preserve('id', $id);
echo $tabs->render();

$deleteform->renderActive($deleteform->getRenderer(), $vars, 'delete.php', 'post');
echo '<br />';

$ticket->setDetails($vars);
$form = new TicketDetailsForm($vars);
$form->addAttributes($whups->getAllTicketAttributesWithNames($id));

$r = $form->getRenderer();
$r->beginInactive($title);
$r->renderFormInactive($form, $vars);
$r->end();

require $registry->get('templates', 'horde') . '/common-footer.inc';
