<?php
/**
 * $Horde: whups/ticket/update.php,v 1.30 2006/09/17 18:46:32 chuck Exp $
 *
 * Copyright 2001-2006 Robert E. Coyle <robertecoyle@hotmail.com>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 */

@define('WHUPS_BASE', dirname(__FILE__) . '/..');
require_once WHUPS_BASE . '/lib/base.php';
require_once WHUPS_BASE . '/lib/Ticket.php';
require_once WHUPS_BASE . '/lib/Forms/EditTicket.php';
require_once 'Horde/Variables.php';
require_once 'Text/Flowed.php';

$ticket = Whups::getCurrentTicket();

if (!Auth::getAuth() ||
    !Whups::hasPermission(array($ticket->get('queue')), 'queue',
                          'update', Auth::getAuth())) {
    $notification->push(_("Permission Denied"), 'horde.error');
    header('Location: ' . Horde::applicationUrl($prefs->getValue('whups_default_view') . '.php', true));
    exit;
}

$vars = Variables::getDefaultVariables();
$vars->set('id', $id = $ticket->getId());
foreach ($ticket->getDetails() as $varname => $value) {
    $vars->add($varname, $value);
}
if ($tid = $vars->get('transaction')) {
    $history = Whups::permissionsFilter($whups->getHistory($ticket->getId()),
                                        'comment', PERMS_READ);
    if (!empty($history[$tid]['comment'])) {
        $flowed = new Text_Flowed(preg_replace("/\s*\n/U", "\n", $history[$tid]['comment']));
        $vars->set('newcomment', $flowed->toFlowed(true));
    }
}

// Edit action.
if ($vars->get('formname') == 'editticketform') {
    $editform = &new EditTicketForm($vars);
    if ($editform->validate($vars)) {
        $editform->getInfo($vars, $info);

        $ticket->change('summary', $info['summary']);
        $ticket->change('state', $info['state']);
        $ticket->change('priority', $info['priority']);
        $ticket->change('due', $info['due']);
        if (!empty($info['newcomment'])) {
            $ticket->change('comment', $info['newcomment']);
        }

        // Update user and group assignments.
        if (Whups::hasPermission(array($vars->get('queue')), 'queue',
                                 'assign', Auth::getAuth())) {
            $ticket->change('owners', array_merge(isset($info['owners']) ? $info['owners'] : array(),
                                                  isset($info['group_owners']) ? $info['group_owners'] : array()));
        }

        // Update attributes.
        $whups->setAttributes($info);

        // Add attachment if one was uploaded.
        if (!empty($info['newattachment']['name'])) {
            $ticket->change('attachment', array('name' => $info['newattachment']['name'],
                                                'tmp_name' => $info['newattachment']['tmp_name']));
        }

        // If there was a new comment and permissions were specified
        // on it, set them.
        if (!empty($info['group'])) {
            $ticket->change('comment-perms', $info['group']);
        }

        $result = $ticket->commit();
        if (is_a($result, 'PEAR_Error')) {
            $notification->push($result, 'horde.error');
        } else {
            $notification->push(_("Ticket Updated"), 'horde.success');
            $ticket->show();
        }
    }
}

$title = '[#' . $id . '] ' . $ticket->get('summary');
require WHUPS_TEMPLATES . '/common-header.inc';
require WHUPS_TEMPLATES . '/menu.inc';
require WHUPS_TEMPLATES . '/prevnext.inc';

$tabs = Whups::getTicketTabs($vars);
$tabs->preserve('id', $id);
echo $tabs->render();

$form = new EditTicketForm($vars, sprintf(_("Update %s"), $title), $whups->getAllTicketAttributesWithNames($id));
$form->renderActive($form->getRenderer(), $vars, 'update.php', 'post');
echo '<br class="spacer" />';

$ticket->setDetails($vars);
$form = new TicketDetailsForm($vars, $title);
$form->addAttributes($whups->getAllTicketAttributesWithNames($id));
$form->renderInactive($form->getRenderer(), $vars);

require $registry->get('templates', 'horde') . '/common-footer.inc';
